summaryrefslogtreecommitdiff
path: root/gdk/gdkcursor.c
diff options
context:
space:
mode:
authorOwen Taylor <otaylor@redhat.com>2002-06-18 20:59:44 +0000
committerOwen Taylor <otaylor@src.gnome.org>2002-06-18 20:59:44 +0000
commit621fb7466a984a45b5d2fc267eac0024d6218030 (patch)
tree3f760dd49587cfc84b71c6989daf5be2b0cbb13d /gdk/gdkcursor.c
parent1371ded54cb57c793a09ccf14c1dfcdcdd6e4a47 (diff)
downloadgtk+-621fb7466a984a45b5d2fc267eac0024d6218030.tar.gz
Replace gdk_cursor_new_for_screen() with gdk_cursor_new_for_display().
Tue Jun 18 14:41:48 2002 Owen Taylor <otaylor@redhat.com> * gdk/gdkcursor.[ch] gdk/x11/gdkcursor-x11.c gdk/x11/gdkprivate-x11.h gdk/win32/gdkcursor-win32.c: Replace gdk_cursor_new_for_screen() with gdk_cursor_new_for_display(). (#85671) * gtk/gtkclist.c gtk/gtkcombo.c gtk/gtkcurve.c gtk/gtkdnd.c gtk/gtkentry.c gtk/gtkhandlebox.c gtk/gtkhsv.c gtk/gtklabel.c gtk/gtkpaned.c gtk/gtktext.c gtk/gtktextview.c gtk/gtktipsquery.c gtk/gtktreeviewcolumn.c: Adapt to above change.
Diffstat (limited to 'gdk/gdkcursor.c')
-rw-r--r--gdk/gdkcursor.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/gdk/gdkcursor.c b/gdk/gdkcursor.c
index dc0b5ee813..d18befe78e 100644
--- a/gdk/gdkcursor.c
+++ b/gdk/gdkcursor.c
@@ -25,7 +25,7 @@
*/
#include "gdkcursor.h"
-#include "gdkscreen.h"
+#include "gdkdisplay.h"
#include "gdkinternals.h"
GType
@@ -83,8 +83,8 @@ gdk_cursor_unref (GdkCursor *cursor)
* gdk_cursor_new:
* @cursor_type: cursor to create
*
* Creates a new cursor from the set of builtin cursors for the default screen.
* See gdk_cursor_new_for_screen().
*
* To make the cursor invisible, use gdk_cursor_new_from_pixmap() to create
* a cursor with no pixels in it.
@@ -94,5 +94,5 @@ gdk_cursor_unref (GdkCursor *cursor)
GdkCursor*
gdk_cursor_new (GdkCursorType cursor_type)
{
- return gdk_cursor_new_for_screen (gdk_get_default_screen(), cursor_type);
+ return gdk_cursor_new_for_display (gdk_get_default_display(), cursor_type);
}
@@ -83,8 +83,8 @@ gdk_cursor_unref (GdkCursor *cursor)
* @cursor_type: cursor to create
*
- * Creates a new cursor from the set of builtin cursors for the default screen.
- * See gdk_cursor_new_for_screen().
+ * Creates a new cursor from the set of builtin cursors for the default display.
+ * See gdk_cursor_new_for_display().
*
* To make the cursor invisible, use gdk_cursor_new_from_pixmap() to create